package train;

import java.util.ArrayList;

import train.car.Car;
import train.locomotive.Locomotive;

/**
 * Beschreibt einen Zug.
 * 
 * @author Owyn
 * @version 2008-06-17
 */
public class Train {
    
    /**
     * Lok des Zugs
     */
    private Locomotive loc;
    /**
     * Liste der Waggons
     */
    private ArrayList cars;
    
    /**
     * Erzeugt einen Zug.
     *
     * @param loc Die Lokomotive des Zugs
     */
    public Train(Locomotive loc) {
        this.loc = loc;
        cars = new ArrayList();
    }
    
    /**
     * H&auml;ngt einen Waggon an das Ende des Zugs.
     *
     * @param car Der neue Waggon
     */   
    public void add(Car car) {
        cars.add(car);
    }
    
    /**
     * Gibt die gesamte Personkapazit&auml;t zur&uuml;ck.
     *
     * @return Personenkapazit&auml;t
     */      
    public int getCapacity() {
        int cap = 0;
        for (int i = 0; i < cars.size(); i++) {
            if (cars.get(i) != null) { // Zur Sicherheit
                // Wichtig: Typecast nach Car, da die ArrayList Objects enthaelt!
                cap += ((Car) cars.get(i)).getCapacity();
            }
        }
        return cap;
    }
    
    /**
     * Gibt die gesamte Zugl&auml;nge zur&uuml;ck.
     *
     * @return Zugl&auml;nge
     */  
    public int getLength() {
        int len = loc.getLength(); // Laenge der Lok
        for (int i = 0; i < cars.size(); i++) {
            if (cars.get(i) != null) {
                len += ((Car) cars.get(i)).getLength();
            }
        }
        return len;
    }
    
    /**
     * Entfernt den letzten Waggon.
     *
     * @return Der entfernte Waggon
     */     
    public Car removeLast() {
        if (cars.size() == 0) return null;
        else return (Car) cars.remove(cars.size() - 1);
    }
    
    /**
     * Gibt eine Textdarstellung des Zugs zur&uuml;ck.
     *
     * @return Textdarstellung
     */ 
    public String toString() {
        StringBuffer s = new StringBuffer();
        
        s.append(loc.toString()); // Lok
        for (int i = 0; i < cars.size(); i++) { // Waggons
            s.append(" <-> ");
            s.append(cars.get(i).toString());
        }
        
        return s.toString();
    }
    
}
